pub struct ServiceSideCapabilityRegistry { /* private fields */ }Implementations
Sourceimpl ServiceSideCapabilityRegistry
impl ServiceSideCapabilityRegistry
pub fn new() -> Self
pub fn register_input_resolver<R>(
&mut self,
resolver: R,
) -> ServiceSideResult<()>where
R: ServiceSideInputResolver + 'static,
pub fn register_tool<T>(&mut self, tool: T) -> ServiceSideResult<()>where
T: ServiceSideTool + 'static,
Sourcepub fn inject_tools(&self, request: &mut UniversalRequest) -> usize
pub fn inject_tools(&self, request: &mut UniversalRequest) -> usize
Inject every registered host tool into the request, preserving any client declaration with the same name as the request owner.
pub async fn resolve_inputs( &self, request: &mut UniversalRequest, ) -> ServiceSideResult<ServiceSideResolutionReport>
pub async fn execute_tool_calls( &self, response: &UniversalResponse, ) -> ServiceSideResult<ServiceSideToolExecution>